@@ -41,7 +41,7 @@ class MainLog(BaseLog):
                  journal_log_enable=True, journal_mq_enable=True, host="", port=5673, virtual_host="",
                  heartbeat_interval=30, name="", password="", confirm=False, is_gevet=True,
                  mq_exchange_name='x.journal'):
-        BaseLog.__init__(self, app_name, prefix_path, f_code, t_code, when=when, backup_count=backup_count,
+        BaseLog.__init__(self, app_name, prefix_path, t_code, f_code, when=when, backup_count=backup_count,
                          journal_log_enable=journal_log_enable)
         self.journal_mq_enable = journal_mq_enable
         if self.journal_mq_enable:
@@ -159,7 +159,7 @@ class MainLog(BaseLog):
                                           total_time=total_time,
                                           order_id=order_id,
                                           phone_num=phone_num,
-                                          method_code=method_code,
+                                          method_code=method_code if method_code else action_code,
                                           f_code=f_code
                                           )
                     except Exception as ex:
